import { createSlice } from '@reduxjs/toolkit'
import persistReducer from 'redux-persist/es/persistReducer'
import storage from 'redux-persist/lib/storage'

export interface NavigationState {
    selectedMenuItem?: string,
    open: boolean,
}

const persistConfig = {
    key: 'navigation',
    storage
}

const initialState = {
    selectedMenuItem: '',
    open: false
}

export const navigationSlice = createSlice({
    name: 'navigation',
    initialState,
    reducers: {
        setSelectedMenuItem: (state, action) => ({...state, selectedMenuItem: action.payload}),
        setOpen: (state, action) => ({...state, open: action.payload}),
    }
})

const navigationReducer = persistReducer(persistConfig, navigationSlice.reducer)

export const { setSelectedMenuItem, setOpen } = navigationSlice.actions

export default navigationReducer
